@@ -82,8 +82,9 @@ get_wfs <- function(shape,
                               layer_name, shape) {
     cat("Request ", startindex + 1, "/", nb_request + 1,
         " downloading...\n", sep = "")
-     res <- st_read(format_url(apikey, layer_name, shape,
-                               startindex = 1000 * startindex),
+     resp <- GET(format_url(apikey, layer_name, shape,
+                            startindex = 1000 * startindex))
+     res <- st_read(resp,
                     quiet = TRUE)
   }
 
@@ -108,7 +109,7 @@ get_wfs <- function(shape,
 
   nb_request <- nb_features %/% 1000
 
-  all_roads_df <- lapply(
+  list_features <- lapply(
     X = 0:nb_request,
     FUN = lapply_function,
     nb_request = nb_request,
@@ -117,18 +118,18 @@ get_wfs <- function(shape,
     shape = shape
   )
 
-  roads <- do.call("rbind", all_roads_df) %>%
+  features <- do.call("rbind", list_features) %>%
     st_as_sf() %>%
     st_make_valid() %>%
     select(-bbox)
 
   if (!is.null(filename)) {
-     st_write(roads, file.path(paste0(filename, ".shp")))
+     st_write(features, file.path(paste0(filename, ".shp")))
      message("The shape is saved at : ", file.path(getwd(),
                                                    paste0(filename, ".shp")))
   }
 
-  return(roads)
+  return(features)
 }
 #'
 #' format url for request
